
### cleanipynb


[![](https://img.shields.io/pypi/v/clean_ipynb.svg)](https://pypi.python.org/pypi/clean_ipynb)
[![](https://img.shields.io/travis/i008/clean_ipynb.svg)](https://travis-ci.org/i008/clean_ipynb)


Cleans up dirty jupyter notebooks


> **WARNING**: Cleaning happens in-place - Be careful


### Usage:

```bash
pip install cleanipynb
cleanipynb path_to_your_notebook.ipynb
```

### Demo:
![](beforeafter.gif)





